@@ -4,4 +4,4 @@ from python_helper.api.src.domain import Constant
 from python_helper.api.src.annotation.EnvironmentAnnotation import EnvironmentVariable
 from python_helper.api.src.annotation.TestAnnotation import Test
 from python_helper.api.src.annotation.MethodAnnotation import Method, Function, FunctionThrough
-from python_helper.api.src.helper import ObjectHelperHelper, SettingHelperHelper, SettingHelperHelper, LogHelperHelper, RandomHelperHelper
+from python_helper.api.src.helper import ObjectHelperHelper, SettingHelperHelper, SettingHelperHelper, LogHelperHelper, RandomHelperHelper, AnnotationHelper
